@@ -2,10 +2,10 @@ import os
 
 HUB_APP_SLUG = ""
 
-HUB_BASE_URI = os.environ.get("HUB_BASE_URI", "https://api-dev-hub.nave.dev")
+HUB_BASE_URI = os.environ.get("HUB_BASE_URI", "")
 HUB_BASE_PREFIX = os.environ.get("HUB_BASE_PREFIX", "/api")
 HUB_BASE_FRONT_URI = os.environ.get(
-    "HUB_BASE_FRONT_URI", "https://develop.hub.nave.dev"
+    "HUB_BASE_FRONT_URI", ""
 )
 
 HUB_PROGRAMMATIC_PREFIX = os.environ.get("HUB_PROGRAMMATIC_PREFIX", "/programmatic")
